@@ -64,6 +64,7 @@ WT_DECLARE_WT_MEMBER
 	 ele = t;
 	 t = t.parentNode;
 	 columnId = t.className.split(' ')[0].substring(7) * 1;
+	 rowIdx = $t.index();
 	 break;
        }
        t = t.parentNode;
@@ -112,8 +113,10 @@ WT_DECLARE_WT_MEMBER
        = wt_tv_contents.style.width
        = cwidth;
 
-     if (headerColumn)
+     if (headerColumn) {
        headerColumnsContainer.style.width = cwidth;
+       APP.layouts2.setDirty(headerColumnsContainer.parentNode);
+     }
 
      header.style.width = (newWidth + 1) + 'px';
      column.style.width = (newWidth + 7) + 'px';
@@ -382,8 +385,10 @@ WT_DECLARE_WT_MEMBER
        var pns = headerColumnsContainer.parentNode.style;
        if (pns && (pns.paddingBottom !== scrollheight + 'px')) {
 	 pns.paddingBottom = scrollheight + 'px';
-	 APP.layouts.adjust(el.children[0].id);
-	 APP.layouts.adjust();
+	 if (APP.layouts) {
+	   APP.layouts.adjust(el.children[0].id);
+	   APP.layouts.adjust();
+	 }
        }
      }
    };
