@@ -72,7 +72,11 @@ class WT_API DomElement
 {
 public:
   enum Mode { ModeCreate, ModeUpdate };
+#ifndef WT_TARGET_JAVA
   typedef std::map<Wt::Property, std::string> PropertyMap;
+#else
+  typedef std::treemap<Wt::Property, std::string> PropertyMap;
+#endif
 
   DomElement(Mode mode, DomElementType type);
   ~DomElement();
@@ -257,12 +261,12 @@ private:
   DomElementType type_;
   std::string  id_;
   int          numManipulations_;
-  std::vector<std::string> methodCalls_;
   int          timeOut_;
   bool         timeOutJSRepeat_;
   EscapeOStream javaScript_;
   std::string  javaScriptEvenWhenDeleted_;
   mutable std::string var_;
+  mutable bool declared_;
 
   AttributeMap    attributes_;
   PropertyMap     properties_;
