@@ -341,13 +341,6 @@ this.initAjaxComm = function(url, handler) {
 	}
 
 	s.onerror = onerror;
-/*
-	s.onreadystatechange = function() {
-	  var rs = s.readyState;
-	  if (rs == 'loaded' && !WT.isOpera)
-	    onerror();
-	};
-*/
 
 	var h = document.getElementsByTagName('head')[0];
 	h.appendChild(s);
@@ -621,6 +614,8 @@ this.getElement = function(id) {
   return el;
 };
 
+this.$ = this.getElement;
+
 this.validate = function(edit) {
   var v;
   if (edit.options)
@@ -649,6 +644,9 @@ this.filter = function(edit, event, tokens) {
 this.widgetPageCoordinates = function(obj) {
   var objX = 0, objY = 0, op;
 
+  if (!obj.parentNode)
+    return { x: 0, y: 0 };
+
   // bug in safari, according to W3C, offsetParent for an area element should
   // be the map element, but safari returns null.
   if (WT.hasTag(obj, "AREA"))
@@ -937,7 +935,9 @@ this.cssPrefix = function(prop) {
     if ((prefixes[i] + prop) in elem.style)
       return prefixes[i];
   }
-}
+
+  return null;
+};
 
 this.boxSizing = function(w) {
   return (w.style['boxSizing']
@@ -1010,7 +1010,11 @@ var captureElement = null;
 this.firedTarget = null;
 
 this.target = function(event) {
-  return WT.firedTarget || event.target || event.srcElement;
+  try {
+    return WT.firedTarget || event.target || event.srcElement;
+  } catch (err) {
+    return null;
+  }
 };
 
 function delegateCapture(e) {
@@ -1404,7 +1408,11 @@ this.positionAtWidget = function(id, atId, orientation, parentInRoot,
 };
 
 this.hasFocus = function(el) {
-  return el == document.activeElement;
+  try {
+    return el == document.activeElement;
+  } catch(e) {
+    return false;
+  }
 };
 
 var html5History = !!(window.history && window.history.pushState);
@@ -1500,8 +1508,12 @@ _$_$endif_$_();
 	}
 
 	var q = stripHashParameter(window.location.search);
-	if (q.length > 1)
+
+	if (q.length > 1) {
+	  if (q.length > 2 && q[0] == '?' && q[1] == '&')
+	    q = q.substr(1);
 	  url += '&' + q.substr(1);
+	}
       }
 
       try {
@@ -1821,14 +1833,28 @@ var dragState = {
 };
 
 function initDragDrop() {
-  window.onresize = function() { doJavaScript(); };
-
   document.body.ondragstart=function() {
     return false;
   };
 }
 
 function dragStart(obj, e) {
+  var t = WT.target(e);
+  if (t) {
+    /*
+     * Ignore drags that start on a scrollbar (#1231)
+     */
+    if (t.offsetWidth > t.clientWidth
+	|| t.offsetHeight > t.clientHeight) {
+      var wc = WT.widgetPageCoordinates(t);
+      var pc = WT.pageCoordinates(e);
+      var x = pc.x - wc.x;
+      var y = pc.y - wc.y;
+      if (x > t.clientWidth || y > t.clientHeight)
+	return true;
+    }
+  }
+
   // drag element attributes:
   //   dwid = dragWidgetId
   //   dsid = dragSourceId
@@ -1892,6 +1918,7 @@ function dragDrag(e) {
     var amts = null;
 
     ds.dropTarget = null;
+
     while (t) {
       amts = t.getAttribute("amts");
       if ((amts != null) && (amts.indexOf(mimeType) != -1)) {
@@ -1930,7 +1957,8 @@ function dragDrag(e) {
 	ds.dropTarget.handleDragDrop('drag', ds.object, e, '', mimeType);
       else
 	ds.object.className = 'Wt-valid-drop';
-    }
+    } else
+      ds.object.className = '';
 
     return false;
   }
@@ -2114,8 +2142,15 @@ function encodeEvent(event, i) {
   if (typeof e.keyCode !== 'undefined')
     result += se + 'keyCode=' + e.keyCode;
 
-  if (typeof e.charCode !== 'undefined')
-    result += se + 'charCode=' + e.charCode;
+  var charCode = 0;
+  if (typeof e.charCode !== 'undefined') {
+    if (e.type == 'keypress')
+      charCode = e.charCode;
+  } else {
+    if (e.type == 'keypress')
+      charCode = e.keyCode;
+  }
+  result += se + 'charCode=' + charCode;
 
   if (e.altKey)
     result += se + 'altKey=1';
@@ -2633,6 +2668,18 @@ function sendUpdate() {
   }
 }
 
+function propagateSize(element, width, height) {
+  if ((typeof element.wtWidth === 'undefined')
+      || (element.wtWidth != width)
+      || (typeof element.wtHeight === 'undefined')
+      || (element.wtHeight != height)) {
+    element.wtWidth = width;
+    element.wtHeight = height;
+
+    emit(element, 'resized', width, height);
+  }
+}
+
 function emit(object, config) {
   var userEvent = new Object(), ei = pendingEvents.length;
   userEvent.signal = "user";
@@ -2860,7 +2907,9 @@ this._p_ = {
 
   response : responseReceived,
   setPage : setPage,
-  setCloseMessage : setCloseMessage
+  setCloseMessage : setCloseMessage,
+
+  propagateSize : propagateSize
 };
 
 this.WT = _$_WT_CLASS_$_;
